#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timeit
version:              2.0
visibility:           public
id:                   timeit-2.0-9v31DY9p9ojLe6jxDFX4lL
key:                  timeit-2.0-9v31DY9p9ojLe6jxDFX4lL
license:              BSD-3-Clause
copyright:            Copyright © 2009, Lennart Augustsson
maintainer:
    Merijn Verstraaten <merijn@inconsistent.nl>, Lennart Augustsson

author:               Lennart Augustsson
homepage:             https://github.com/merijn/timeit
synopsis:             Time monadic computations with an IO base.
description:
    A simple wrapper to show the used CPU time of monadic computation with an
    IO base.

category:             System
abi:                  6d430a0787dc73104aa7dcb35841b6b2
exposed:              True
exposed-modules:      System.TimeIt
import-dirs:          /usr/lib/ghc-8.10.5/site-local/timeit-2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/timeit-2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/timeit-2.0
hs-libraries:         HStimeit-2.0-9v31DY9p9ojLe6jxDFX4lL
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-timeit/html/timeit.haddock
haddock-html:         /usr/share/doc/haskell-timeit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

